Skip to content

Represents the "Andamento" structure in SEI, which tracks process events.

Usage

Andamento(
  IdAndamento = NULL,
  IdTarefa = NULL,
  IdTarefaModulo = NULL,
  Descricao = NULL,
  DataHora = NULL,
  Unidade = NULL,
  Usuario = NULL,
  Atributos = list()
)

Arguments

IdAndamento

Character. Internal identifier of the andamento.

IdTarefa

Character. Identifier of the associated task.

IdTarefaModulo

Character. Identifier of the module task.

Descricao

Character. Text describing the andamento.

DataHora

Character. Date/time when the andamento was generated.

Unidade

A Unidade object describing the unit that created the andamento.

Usuario

A Usuario object describing the user who created the andamento.

Atributos

A list of AtributoAndamento objects (can be empty).

Value

An S3 object of class "Andamento".