Retrieves the stored SEI credentials for a given service_name from the keyring.
If the keyring package is missing or if retrieval fails, the function displays a
message instead of throwing an error, and returns NULL.
Retrieves the stored SEI credentials for a given service_name from the keyring.
If the keyring package is missing or if retrieval fails, the function displays a
message instead of throwing an error, and returns NULL.